@@ -18,7 +18,7 @@ from .streams import EOF_MARKER, FlowControlStreamReader
 from .multidict import CIMultiDictProxy, MultiDictProxy, MultiDict, CIMultiDict
 from .multipart import MultipartWriter
 
-PY_34 = sys.version_info >= (3, 4)
+PY_341 = sys.version_info >= (3, 4, 1)
 
 HTTP_PORT = 80
 HTTPS_PORT = 443
@@ -463,7 +463,10 @@ class ClientRequest:
 
     def terminate(self):
         if self._writer is not None:
-            if not self.loop.is_closed():
+            if hasattr(self.loop, 'is_closed'):
+                if not self.loop.is_closed():
+                    self._writer.cancel()
+            else:
                 self._writer.cancel()
             self._writer = None
 
@@ -507,7 +510,7 @@ class ClientResponse:
         if loop.get_debug():
             self._source_traceback = traceback.extract_stack(sys._getframe(1))
 
-    if PY_34:
+    if PY_341:
         def __del__(self):
             if self._closed:
                 return
@@ -591,8 +594,9 @@ class ClientResponse:
 
         self._closed = True
 
-        if self._loop.is_closed():
-            return
+        if hasattr(self._loop, 'is_closed'):
+            if self._loop.is_closed():
+                return
 
         if self._connection is not None:
             if self.content and not self.content.at_eof():
