@@ -80,7 +80,7 @@ class Request(dict, HeadersMixin):
                     hdrs.METH_TRACE, hdrs.METH_DELETE}
 
     def __init__(self, app, message, payload, transport, reader, writer, *,
-                 _HOST=hdrs.HOST):
+                 _HOST=hdrs.HOST, secure_proxy_ssl_header=None):
         self._app = app
         self._version = message.version
         self._transport = transport
@@ -108,6 +108,24 @@ class Request(dict, HeadersMixin):
         self._cookies = None
 
         self._read_bytes = None
+        self._has_body = not payload.at_eof()
+
+        self._secure_proxy_ssl_header = secure_proxy_ssl_header
+
+    @property
+    def scheme(self):
+        """A string representing the scheme of the request.
+
+        'http' or 'https'.
+        """
+        if self._transport.get_extra_info('sslcontext'):
+            return 'https'
+        secure_proxy_ssl_header = self._secure_proxy_ssl_header
+        if secure_proxy_ssl_header is not None:
+            header, value = secure_proxy_ssl_header
+            if self._headers.get(header) == value:
+                return 'https'
+        return 'http'
 
     @property
     def method(self):
@@ -177,10 +195,7 @@ class Request(dict, HeadersMixin):
 
     @property
     def headers(self):
-        """A case-insensitive multidict with all headers.
-
-        Lazy property.
-        """
+        """A case-insensitive multidict proxy with all headers."""
         return self._headers
 
     @property
@@ -227,6 +242,11 @@ class Request(dict, HeadersMixin):
         """Return raw payload stream."""
         return self._payload
 
+    @property
+    def has_body(self):
+        """Return True if request has HTTP BODY, False otherwise."""
+        return self._has_body
+
     @asyncio.coroutine
     def release(self):
         """Release request.
