@@ -2,6 +2,7 @@
 """Tests for aiohttp/client.py"""
 
 import asyncio
+import gc
 import unittest
 from unittest import mock
 import sys
@@ -14,7 +15,7 @@ from aiohttp.client_reqrep import ClientRequest, ClientResponse
 from http.cookies import SimpleCookie
 
 
-PY_34 = sys.version_info >= (3, 4)
+PY_341 = sys.version_info >= (3, 4, 1)
 
 
 class TestClientSession(unittest.TestCase):
@@ -353,13 +354,14 @@ class TestClientSession(unittest.TestCase):
         self.assertTrue(session.closed)
         self.assertTrue(conn.closed)
 
-    @unittest.skipUnless(PY_34, "Requires Python 3.4+")
+    @unittest.skipUnless(PY_341, "Requires Python 3.4.1+")
     def test_del(self):
         conn = self.make_open_connector()
         session = ClientSession(loop=self.loop, connector=conn)
 
         with self.assertWarns(ResourceWarning):
             del session
+            gc.collect()
 
 
 class TestCLientRequest(unittest.TestCase):
