@@ -4,7 +4,8 @@ from unittest import mock
 from aiohttp import hdrs
 from aiohttp.multidict import CIMultiDict
 from aiohttp.web import Request, StreamResponse, Response
-from aiohttp.protocol import RawRequestMessage, HttpVersion11
+from aiohttp.protocol import HttpVersion, HttpVersion11, HttpVersion10
+from aiohttp.protocol import RawRequestMessage
 
 
 class TestStreamResponse(unittest.TestCase):
@@ -17,9 +18,12 @@ class TestStreamResponse(unittest.TestCase):
         self.loop.close()
 
     def make_request(self, method, path, headers=CIMultiDict()):
-        self.app = mock.Mock()
         message = RawRequestMessage(method, path, HttpVersion11, headers,
                                     False, False)
+        return self.request_from_message(message)
+
+    def request_from_message(self, message):
+        self.app = mock.Mock()
         self.payload = mock.Mock()
         self.transport = mock.Mock()
         self.reader = mock.Mock()
@@ -99,7 +103,7 @@ class TestStreamResponse(unittest.TestCase):
         with self.assertRaises(RuntimeError):
             resp.charset = 'koi8-r'
 
-    @mock.patch('aiohttp.web.ResponseImpl')
+    @mock.patch('aiohttp.web_reqrep.ResponseImpl')
     def test_start(self, ResponseImpl):
         req = self.make_request('GET', '/')
         resp = StreamResponse()
@@ -116,7 +120,7 @@ class TestStreamResponse(unittest.TestCase):
         with self.assertRaises(RuntimeError):
             resp.start(req2)
 
-    @mock.patch('aiohttp.web.ResponseImpl')
+    @mock.patch('aiohttp.web_reqrep.ResponseImpl')
     def test_chunked_encoding(self, ResponseImpl):
         req = self.make_request('GET', '/')
         resp = StreamResponse()
@@ -128,7 +132,7 @@ class TestStreamResponse(unittest.TestCase):
         msg = resp.start(req)
         self.assertTrue(msg.chunked)
 
-    @mock.patch('aiohttp.web.ResponseImpl')
+    @mock.patch('aiohttp.web_reqrep.ResponseImpl')
     def test_chunk_size(self, ResponseImpl):
         req = self.make_request('GET', '/')
         resp = StreamResponse()
@@ -142,7 +146,7 @@ class TestStreamResponse(unittest.TestCase):
         msg.add_chunking_filter.assert_called_with(8192)
         self.assertIsNotNone(msg.filter)
 
-    @mock.patch('aiohttp.web.ResponseImpl')
+    @mock.patch('aiohttp.web_reqrep.ResponseImpl')
     def test_compression_no_accept(self, ResponseImpl):
         req = self.make_request('GET', '/')
         resp = StreamResponse()
@@ -155,7 +159,7 @@ class TestStreamResponse(unittest.TestCase):
         msg = resp.start(req)
         self.assertFalse(msg.add_compression_filter.called)
 
-    @mock.patch('aiohttp.web.ResponseImpl')
+    @mock.patch('aiohttp.web_reqrep.ResponseImpl')
     def test_force_compression_no_accept(self, ResponseImpl):
         req = self.make_request('GET', '/')
         resp = StreamResponse()
@@ -169,7 +173,7 @@ class TestStreamResponse(unittest.TestCase):
         self.assertTrue(msg.add_compression_filter.called)
         self.assertIsNotNone(msg.filter)
 
-    @mock.patch('aiohttp.web.ResponseImpl')
+    @mock.patch('aiohttp.web_reqrep.ResponseImpl')
     def test_compression(self, ResponseImpl):
         req = self.make_request(
             'GET', '/',
@@ -189,7 +193,7 @@ class TestStreamResponse(unittest.TestCase):
         resp = StreamResponse()
         resp.start(self.make_request('GET', '/'))
 
-        with self.assertRaises(TypeError):
+        with self.assertRaises(AssertionError):
             resp.write(123)
 
     def test_write_before_start(self):
@@ -291,15 +295,15 @@ class TestStreamResponse(unittest.TestCase):
         resp.set_cookie('name', 'value', domain='example.com',
                         path='/home', expires='123', max_age='10',
                         secure=True, httponly=True, version='2.0')
-        self.assertEqual(str(resp.cookies),
-                         'Set-Cookie: name=value; '
-                         'Domain=example.com; '
+        self.assertEqual(str(resp.cookies).lower(),
+                         'set-cookie: name=value; '
+                         'domain=example.com; '
                          'expires=123; '
                          'httponly; '
-                         'Max-Age=10; '
-                         'Path=/home; '
+                         'max-age=10; '
+                         'path=/home; '
                          'secure; '
-                         'Version=2.0')
+                         'version=2.0')
 
     def test_response_cookie__issue_del_cookie(self):
         resp = StreamResponse()
@@ -337,6 +341,41 @@ class TestStreamResponse(unittest.TestCase):
         self.assertFalse(resp.keep_alive)
         self.assertTrue(msg.closing)
 
+    def test___repr__(self):
+        req = self.make_request('GET', '/path/to')
+        resp = StreamResponse(reason=301)
+        resp.start(req)
+        self.assertEqual("<StreamResponse 301 GET /path/to >", repr(resp))
+
+    def test___repr__not_started(self):
+        resp = StreamResponse(reason=301)
+        self.assertEqual("<StreamResponse 301 not started>", repr(resp))
+
+    def test_keep_alive_http10(self):
+        message = RawRequestMessage('GET', '/', HttpVersion10, CIMultiDict(),
+                                    True, False)
+        req = self.request_from_message(message)
+        resp = StreamResponse()
+        resp.start(req)
+        self.assertFalse(resp.keep_alive)
+
+        headers = CIMultiDict(Connection='keep-alive')
+        message = RawRequestMessage('GET', '/', HttpVersion10, headers,
+                                    False, False)
+        req = self.request_from_message(message)
+        resp = StreamResponse()
+        resp.start(req)
+        self.assertEqual(resp.keep_alive, True)
+
+    def test_keep_alive_http09(self):
+        headers = CIMultiDict(Connection='keep-alive')
+        message = RawRequestMessage('GET', '/', HttpVersion(0, 9), headers,
+                                    False, False)
+        req = self.request_from_message(message)
+        resp = StreamResponse()
+        resp.start(req)
+        self.assertFalse(resp.keep_alive)
+
 
 class TestResponse(unittest.TestCase):
 
